@@ -5,8 +5,8 @@ var (
 )
 
 type Vector struct {
-	x int
-	y int
+	X int
+	Y int
 }
 
 func NewVector(x, y int) *Vector {
@@ -14,10 +14,14 @@ func NewVector(x, y int) *Vector {
 }
 
 func (v *Vector) Add__0(x int, y int) {
-	v.x += x
-	v.y += y
+	v.X += x
+	v.Y += y
 }
 
 func (v *Vector) Add__1(o *Vector) {
-	v.Add__0(o.x, o.y)
+	v.Add__0(o.X, o.Y)
+}
+
+func (v *Vector) Self() *Vector {
+	return v
 }
